#include <LiquidCrystal_I2C.h>
#include <Servo.h>
#include <Wire.h>

#define Buton1 2
#define Buton2 3
#define Buton3 4
#define Buzzer 10
#define ServoM 9

LiquidCrystal_I2C lcd(0x27, 20, 4);
Servo servo;

const char categories[][21] = {"Trivia", "Physical Challenge", "Truth", "Dare", "Never have I ever"};
const char triviaCat[][34] = {"What is the capital of Australia?", "What is the biggest ocean?", "Who wrote To Kill a Mockingbird?"};
const char physCat[][35] = {"Do 10 jumping jacks in 10 seconds.", "Hold a plank for 30 seconds.", "Do 10 lunges."};
const char truthCat[][40] = {"What is your biggest fear?", "Have you ever cheated on a test?", "What is the worst lie you've ever told?"};
const char dareCat[][37] = {"Text a random person you miss them.", "Sing a song in a funny voice.", "ask someone random their zodiac sign"};
const char neverCat[][34] = {".. stolen something from a store.", ".. gone on a blind date.", "..had a crush on a teacher."};

unsigned long previousBuzzTime = 0;
unsigned long interval = 0;

void setup() {
  Serial.begin(9600);
  pinMode(A0, INPUT);
  // pinMode(Buton1, INPUT_PULLUP);
  // pinMode(Buton2, INPUT_PULLUP);
  // pinMode(Buton3, INPUT_PULLUP);
  pinMode(Buton1, INPUT);
  pinMode(Buton2, INPUT);
  pinMode(Buton3, INPUT);
  pinMode(Buzzer, OUTPUT);
  servo.attach(ServoM);
  Wire.begin();
  lcd.begin(20, 4);
  lcd.backlight();
  lcd.clear();

}

int randomFunc(int x) {
  int seed = analogRead(A0);
  randomSeed(seed);
  switch (x) {
    // case 1 - servomotor
    case (1):
      return (random(3) * 500);
    // case 2 - category
    case (2):
      return random(5);
    // case 3 - questions
    case (3):
      return random(3); // to be modified for more Qs!!
  }
}

void chooseQuestion(int categoryIndex, int questionIndex) {
  lcd.clear();
  lcd.setCursor(0, 0);
  int q; 
  switch(categoryIndex) {
    case (0): // trivia
      lcd.clear();
      lcd.setCursor(0, 1);
      lcd.print(triviaCat[questionIndex]);
      break;
    case (1): // phys
      lcd.clear();
      lcd.setCursor(0, 1);
      lcd.print(physCat[questionIndex]);
       break;
    case (2): // truth
      lcd.clear();
      lcd.setCursor(0, 1);
      lcd.print(truthCat[questionIndex]);
       break;
    case (3): // dare
      lcd.clear();
      lcd.setCursor(0, 1);
      lcd.print(dareCat[questionIndex]);
       break;
    case (4): // never
      lcd.clear();
      lcd.setCursor(0, 1);
      lcd.print(neverCat[questionIndex]);
      break;
  }
}

void playRandomSound() {
  if (millis() - previousBuzzTime >= interval) {
    int tune = random(1, 4);  // Randomly select a tune
    
    // Play different tunes based on the randomly selected tune
    switch (tune) {
      case 1:
        // Play tune 1
        tone(Buzzer, 440, 500);
        delay(500);  // Delay between tones
        tone(Buzzer, 880, 500);
        // Add more tones as needed for the tune
        break;
      case 2:
        // Play tune 2
        tone(Buzzer, 523, 300);  
        delay(300);  // Delay between tones
        tone(Buzzer, 659, 300);  
        break;
      case 3:
        // Play tune 3
        tone(Buzzer, 392, 200);  
        delay(200);  // Delay between tones
        tone(Buzzer, 523, 200);
        break;
    }
    
    interval = random(60000, 180000);  // Random interval between 1 and 3 minutes
    previousBuzzTime = millis();
  }
}

void loop() {
  playRandomSound();

  if (digitalRead(Buton1) == HIGH) {
    // Set servo to the desired position
    servo.write(0);

    // Get random servo motor spin duration
    int spinDuration = randomFunc(1);

    delay(spinDuration);

    // Set servo back to the initial position
    servo.write(90);
  }

  int categoryIndex;
  int questionIndex;

  if (digitalRead(Buton2) == HIGH) {
    lcd.clear();
    lcd.setCursor(0, 0);
    categoryIndex = randomFunc(2);
    lcd.print(categories[categoryIndex]);
  }


  if (digitalRead(Buton3) == HIGH) {
    questionIndex = (randomFunc(3)); //0 sau 1, indexu intrebarii
    chooseQuestion(categoryIndex, questionIndex);
  }
  
}
